@@ -17,7 +17,18 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+
+  In addition, as a special exception, the copyright holders give
+  permission to link the code of this program with any edition of
+  the Qt library by Trolltech AS, Norway (or with modified versions
+  of Qt that use the same license as Qt), and distribute linked
+  combinations including the two.  You must obey the GNU General
+  Public License in all respects for all of the code used other than
+  Qt. If you modify this file, you may extend this exception to
+  your version of the file, but you are not obligated to do so.  If
+  you do not wish to do so, delete this exception statement from
+  your version.
 
 **************************************************************************** */
 
@@ -110,6 +121,15 @@ void CatalogManager::init()
    _replaceDialog=0;
 
    _project = KBabel::ProjectManager::open(_configFile);
+   
+   if ( _project == NULL )
+   {
+	KMessageBox::error( this, i18n("Cannot open project file\n%1").arg(_configFile)
+	    , i18n("Project File Error"));
+	    
+	_project = KBabel::ProjectManager::open(KBABEL_DEFAULTPROJECT);
+   }
+   
    connect( _project, SIGNAL (signalCatManSettingsChanged())
 	, this, SLOT (updateSettings()));
 
@@ -118,7 +138,7 @@ void CatalogManager::init()
    layout->setMargin(0);
    layout->setSpacing(KDialog::spacingHint());
 
-   _catalogManager=new CatalogManagerView(_configFile, view,"catalog manager");
+   _catalogManager=new CatalogManagerView(_project, view,"catalog manager");
    layout->addWidget(_catalogManager);
    layout->setStretchFactor(_catalogManager,1);
 
@@ -414,6 +434,7 @@ void CatalogManager::setupActions()
     (void)new KAction( i18n( "Show Diff" ), 0, _catalogManager,
       SLOT( cvsDiff( ) ), actionCollection( ), "cvs_diff" );
 
+    // CVS
     actionMap["cvs_update"]        = NEEDS_PO | NEEDS_PO_CVS;
     actionMap["cvs_update_marked"] = NEEDS_PO | NEEDS_PO_CVS | NEEDS_MARK;
     actionMap["cvs_commit"]        = NEEDS_PO | NEEDS_PO_CVS;
@@ -422,7 +443,45 @@ void CatalogManager::setupActions()
     actionMap["cvs_status_marked"] = NEEDS_PO | NEEDS_PO_CVS | NEEDS_MARK;
     actionMap["cvs_diff"]          = NEEDS_PO | NEEDS_PO_CVS;
 
-    // Actions for POT files
+    // SVN submenu
+    // Actions for PO files
+    (void)new KAction( i18n( "Update" ), "down", 0, _catalogManager,
+    SLOT( svnUpdate( ) ), actionCollection( ), "svn_update" );
+    (void)new KAction( i18n( "Update Marked" ), 0, _catalogManager,
+    SLOT( svnUpdateMarked( ) ), actionCollection( ), "svn_update_marked" );
+    (void)new KAction( i18n( "Commit" ), "up", 0, _catalogManager,
+    SLOT( svnCommit( ) ), actionCollection( ), "svn_commit" );
+    (void)new KAction( i18n( "Commit Marked" ), 0, _catalogManager,
+    SLOT( svnCommitMarked( ) ), actionCollection( ), "svn_commit_marked" );
+    (void)new KAction( i18n( "Status (Local)" ), 0, _catalogManager,
+    SLOT( svnStatusLocal() ), actionCollection( ), "svn_status_local" );
+    (void)new KAction( i18n( "Status (Local) for Marked" ), 0, _catalogManager,
+    SLOT( svnStatusLocalMarked() ), actionCollection( ), "svn_status_local_marked" );
+    (void)new KAction( i18n( "Status (Remote)" ), 0, _catalogManager,
+    SLOT( svnStatusRemote() ), actionCollection( ), "svn_status_remote" );
+    (void)new KAction( i18n( "Status (Remote) for Marked" ), 0, _catalogManager,
+    SLOT( svnStatusRemoteMarked() ), actionCollection( ), "svn_status_remote_marked" );
+    (void)new KAction( i18n( "Show Diff" ), 0, _catalogManager,
+    SLOT( svnDiff( ) ), actionCollection( ), "svn_diff" );
+    (void)new KAction( i18n( "Show Information" ), 0, _catalogManager,
+    SLOT( svnInfo() ), actionCollection( ), "svn_info" );
+    (void)new KAction( i18n( "Show Information for Marked" ), 0, _catalogManager,
+    SLOT( svnInfoMarked() ), actionCollection( ), "svn_info_marked" );
+
+    // SVN
+    actionMap["svn_update"]        = NEEDS_PO | NEEDS_PO_SVN;
+    actionMap["svn_update_marked"] = NEEDS_PO | NEEDS_PO_SVN | NEEDS_MARK;
+    actionMap["svn_commit"]        = NEEDS_PO | NEEDS_PO_SVN;
+    actionMap["svn_commit_marked"] = NEEDS_PO | NEEDS_PO_SVN | NEEDS_MARK;
+    actionMap["svn_status_local"]        = NEEDS_PO | NEEDS_PO_SVN;
+    actionMap["svn_status_local_marked"] = NEEDS_PO | NEEDS_PO_SVN | NEEDS_MARK;
+    actionMap["svn_status_remote"]        = NEEDS_PO | NEEDS_PO_SVN;
+    actionMap["svn_status_remote_marked"] = NEEDS_PO | NEEDS_PO_SVN | NEEDS_MARK;
+    actionMap["svn_diff"]          = NEEDS_PO | NEEDS_PO_SVN;
+    actionMap["svn_info"]          = NEEDS_PO | NEEDS_PO_SVN;
+    actionMap["svn_info_marked"]   = NEEDS_PO | NEEDS_PO_SVN | NEEDS_MARK;
+
+    // CVS Actions for POT files
     (void)new KAction( i18n( "Update Templates" ), 0, _catalogManager,
       SLOT( cvsUpdateTemplate( ) ), actionCollection( ), "cvs_update_template" );
     (void)new KAction( i18n( "Update Marked Templates" ), 0, _catalogManager,
@@ -437,6 +496,21 @@ void CatalogManager::setupActions()
     actionMap["cvs_commit_template"]        = NEEDS_POT | NEEDS_POT_CVS;
     actionMap["cvs_commit_marked_template"] = NEEDS_POT | NEEDS_POT_CVS | NEEDS_MARK;
 
+    // SVN Actions for POT files
+    (void)new KAction( i18n( "Update Templates" ), 0, _catalogManager,
+    SLOT( svnUpdateTemplate( ) ), actionCollection( ), "svn_update_template" );
+    (void)new KAction( i18n( "Update Marked Templates" ), 0, _catalogManager,
+    SLOT( svnUpdateMarkedTemplate( ) ), actionCollection( ), "svn_update_marked_template" );
+    (void)new KAction( i18n( "Commit Templates" ), 0, _catalogManager,
+    SLOT( svnCommitTemplate( ) ), actionCollection( ), "svn_commit_template" );
+    (void)new KAction( i18n( "Commit Marked Templates" ), 0, _catalogManager,
+    SLOT( svnCommitMarkedTemplate( ) ), actionCollection( ), "svn_commit_marked_template" );
+
+    actionMap["svn_update_template"]        = NEEDS_POT | NEEDS_POT_SVN;
+    actionMap["svn_update_marked_template"] = NEEDS_POT | NEEDS_POT_SVN | NEEDS_MARK;
+    actionMap["svn_commit_template"]        = NEEDS_POT | NEEDS_POT_SVN;
+    actionMap["svn_commit_marked_template"] = NEEDS_POT | NEEDS_POT_SVN | NEEDS_MARK;
+
     // settings menu
     // FIXME: KStdAction::preferences(this, SLOT( optionsPreferences()), actionCollection());
 
@@ -578,6 +652,9 @@ void CatalogManager::openFile(QString filename, QString package)
         }
 
         kdDebug(KBABEL_CATMAN) << callfunc << endl;
+	
+	// update the user timestamp for KBabel to get it a focus
+	kapp->updateRemoteUserTimestamp ("kbabel");
 
         if( !client->send("kbabel","KBabelIFace", callfunc, data) )
             KMessageBox::error(this, i18n("Can not send a message to KBabel.\n"
@@ -609,6 +686,9 @@ void CatalogManager::openFile(QString filename, QString package, int msgid)
 
         kdDebug(KBABEL_CATMAN) << callfunc << endl;
 
+	// update the user timestamp for KBabel to get it a focus
+	kapp->updateRemoteUserTimestamp ("kbabel");
+
         if( !client->send("kbabel","KBabelIFace", callfunc, data) )
             KMessageBox::error(this, i18n("Can not send a message to KBabel.\n"
                                           "Please check your installation of KDE."));
@@ -637,6 +717,9 @@ void CatalogManager::openFileInNewWindow(QString filename, QString package)
             callfunc="openURL(QCString, QCString, WId,int,QCString)";
         }
 
+	// update the user timestamp for KBabel to get it a focus
+	kapp->updateRemoteUserTimestamp ("kbabel");
+
         if( !client->send("kbabel","KBabelIFace", callfunc, data) )
             KMessageBox::error(this, i18n("Can not send a message to KBabel.\n"
                                           "Please check your installation of KDE."));
@@ -664,6 +747,9 @@ void CatalogManager::openTemplate(QString openFilename,QString saveFilename,QStr
             callfunc="openTemplate(QCString,QCString,QCString,int,QCString)";
         }
 
+	// update the user timestamp for KBabel to get it a focus
+	kapp->updateRemoteUserTimestamp ("kbabel");
+
         if( !client->send("kbabel","KBabelIFace", callfunc, data) )
             KMessageBox::error(this, i18n("Can not send a message to KBabel.\n"
                                           "Please check your installation of KDE."));
@@ -691,6 +777,9 @@ void CatalogManager::openTemplateInNewWindow(QString openFilename,QString saveFi
             callfunc="openTemplate(QCString,QCString,QCString,int,QCString)";
         }
 
+	// update the user timestamp for KBabel to get it a focus
+	kapp->updateRemoteUserTimestamp ("kbabel");
+
         if( !client->send("kbabel","KBabelIFace", callfunc, data) )
             KMessageBox::error(this, i18n("Can not send a message to KBabel.\n"
                                           "Please check your installation of KDE."));
@@ -707,6 +796,10 @@ void CatalogManager::spellcheck()
         QByteArray data;
         QDataStream arg(data, IO_WriteOnly);
         arg << fileList;
+
+	// update the user timestamp for KBabel to get it a focus
+	kapp->updateRemoteUserTimestamp ("kbabel");
+
         if( !client->send("kbabel","KBabelIFace", "spellcheck(QStringList)", data) )
             KMessageBox::error(this, i18n("Can not send a message to KBabel.\n"
                                           "Please check your installation of KDE."));
@@ -723,6 +816,10 @@ void CatalogManager::markedSpellcheck()
         QByteArray data;
         QDataStream arg(data, IO_WriteOnly);
         arg << fileList;
+
+	// update the user timestamp for KBabel to get it a focus
+	kapp->updateRemoteUserTimestamp ("kbabel");
+
         if( !client->send("kbabel","KBabelIFace", "spellcheck(QStringList)", data) )
             KMessageBox::error(this, i18n("Can not send a message to KBabel.\n"
                                           "Please check your installation of KDE."));
@@ -738,7 +835,7 @@ bool CatalogManager::startKBabel()
 
     // find out, if there is a running kbabel
     QCStringList apps = client->registeredApplications();
-    for( QCStringList::Iterator it = apps.begin() ; it != apps.end() ; it++ )
+    for( QCStringList::Iterator it = apps.begin() ; it != apps.end() ; ++it )
     {
         QString clientID = *it;
         if( clientID=="kbabel" )
@@ -846,11 +943,8 @@ void CatalogManager::find()
         _findOptions = _findDialog->findOpts();
 
         // get from options the information for ignoring text parts
-        config = new KConfig( "kbabelrc");
-        config->setGroup( "Misc" );
-        KBabel::Defaults::Misc defaultMisc;
-        _findOptions.contextInfo = QRegExp( config->readEntry( "contextInfo", defaultMisc.contextInfo().pattern() ) );
-        _findOptions.accelMarker = (config->readEntry( "accelMarker", QString(defaultMisc.accelMarker()) ))[0];
+        _findOptions.contextInfo = QRegExp( _project->miscSettings().contextInfo );
+        _findOptions.accelMarker = _project->miscSettings().accelMarker;
 
         _foundFilesList.clear();
         kdDebug(KBABEL_CATMAN) << "Calling catalogmanagerview::find" << endl;
@@ -929,11 +1023,8 @@ void CatalogManager::replace()
         _findOptions = options;
 
         // get from options the information for ignoring text parts
-        config = new KConfig( "kbabelrc");
-        config->setGroup( "Misc" );
-        KBabel::Defaults::Misc defaultMisc;
-        options.contextInfo = QRegExp( config->readEntry( "contextInfo", defaultMisc.contextInfo().pattern() ) );
-        options.accelMarker = (config->readEntry( "accelMarker", QString(defaultMisc.accelMarker()) ))[0];
+        options.contextInfo = QRegExp( _project->miscSettings().contextInfo );
+        options.accelMarker = _project->miscSettings().accelMarker;
 
         _foundFilesList.clear();
         QString url = _catalogManager->find(options, _toBeSearched );
@@ -1101,7 +1192,7 @@ void CatalogManager::projectOpen()
     QString oldproject = _project->filename();
     if( oldproject == KBABEL_DEFAULTPROJECT )
     {
-        oldproject = "";
+        oldproject = QString();
     }
     QString file = KFileDialog::getOpenFileName(oldproject, i18n("*|All Files"), this);
     if (file.isEmpty())
@@ -1155,6 +1246,9 @@ void CatalogManager::projectConfigure()
 {
     KBabel::ProjectDialog* _projectDialog = new ProjectDialog(_project);
 
+    connect (_projectDialog, SIGNAL (settingsChanged())
+	, this, SLOT (updateSettings()));
+
     // settings are updated via signals
     _projectDialog->exec();
 
