@@ -18,7 +18,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
   In addition, as a special exception, the copyright holders give
   permission to link the code of this program with any edition of
@@ -481,6 +481,7 @@ IdentityPreferences::IdentityPreferences(QWidget* parent, const QString& project
     connect(_testPluralButton, SIGNAL(clicked()), this
             , SLOT(testPluralForm()));
 
+    // ### FIXME: "KDE >= 2.2" should be replaced
     QString msg=i18n("<qt><p><b>Number of singular/plural forms</b></p>\n"
             "<p><b>Note</b>: This option is KDE specific at the moment. "
             "If you are not translating a KDE application, you can safely "
@@ -890,7 +891,7 @@ CatmanPreferences::CatmanPreferences(QWidget* parent)
     QHBox* hbox = new QHBox(box);
     hbox->setSpacing(KDialog::spacingHint());
 
-    KFile::Mode mode = static_cast<KFile::Mode>( KFile::Directory | KFile::ExistingOnly | KFile::LocalOnly );
+    const KFile::Mode mode = static_cast<KFile::Mode>( KFile::Directory | KFile::ExistingOnly | KFile::LocalOnly );
 	
 												
     _poDirEdit = new KURLRequester(hbox, "kcfg_PoBaseDir");
@@ -929,6 +930,7 @@ CatmanPreferences::CatmanPreferences(QWidget* parent)
 
     _killButton = new QCheckBox( i18n("&Kill processes on exit") , box, "kcfg_KillCmdOnExit" );
 
+    // ### FIXME: s/It's/It is/ (especially that it is folowed by "not")
     QWhatsThis::add( _killButton , i18n("<qt><p><b>Kill processes on exit</b></p>\n"
 "<p>If you check this, KBabel tries to kill the processes, that have not exited already when KBabel exits,\n"
 "by sending a kill signal to them.</p>\n"
@@ -941,6 +943,19 @@ CatmanPreferences::CatmanPreferences(QWidget* parent)
 "<p>If you check this, KBabel will create an index for each PO file to speed up the find/replace functions.</p>\n"
 "<p>NOTE: This will slow down updating the file information considerably.</p></qt>") );
 
+    m_msgfmtButton = new QCheckBox( i18n("Run &msgfmt before processing a file"), box, "kcfg_msgfmt" );
+
+    QWhatsThis::add( m_msgfmtButton, i18n("<qt><p><b>Run msgfmt before processing a file</b></p>"
+        "<p>If you check this, KBabel will run Gettext's "
+        "msgfmt tool before processing a file.</p>"
+        "<p>It is recommended to check this setting, even if it makes the processing slower. "
+        "Checking this setting is the default.</p>"
+        "<p>Unchecking is useful for slow computers and when you want "
+        "to translate PO files that are not supported by the current version "
+        "of the Gettext tools that are on your system. "
+        "The drawback of unchecking is that barely not any syntax checking is done by the processing code, "
+        "so that invalid PO files could be shown as good ones, "
+        "even if Gettext tools would reject such files.</p></qt>") );
 
     layout->addStretch(1);
 
@@ -959,6 +974,7 @@ void CatmanPreferences::defaults(const CatManSettings& settings)
 
    _killButton->setChecked(settings.killCmdOnExit );
    _indexButton->setChecked(settings.indexWords );
+   m_msgfmtButton->setChecked( settings.msgfmt );
 }
 
 DirCommandsPreferences::DirCommandsPreferences(QWidget* parent)
@@ -1141,10 +1157,13 @@ SourceContextPreferences::SourceContextPreferences(QWidget* parent): QWidget(par
     box->setSpacing(KDialog::spacingHint());
     QLabel* tempLabel=new QLabel(i18n("&Base folder for source code:"),box);
 
-    _coderootEdit = new QLineEdit(box, "kcfg_CodeRoot");
-    tempLabel->setBuddy(_coderootEdit);
+    const KFile::Mode mode = static_cast<KFile::Mode>( KFile::Directory | KFile::ExistingOnly | KFile::LocalOnly );
+    _coderootEdit = new KURLRequester ( box, "kcfg_CodeRoot" );
+    _coderootEdit->setMode( mode );
+    _coderootEdit->setMinimumSize( 250, _coderootEdit->sizeHint().height() );
+    tempLabel->setBuddy( _coderootEdit );
     layout->addWidget(box);
-
+												
     // FIXME: use KConfigXT    
     _pathsEditor = new KListEditor(page);
     _pathsEditor->setTitle(i18n("Path Patterns"));
