@@ -18,7 +18,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
   In addition, as a special exception, the copyright holders give
   permission to link the code of this program with any edition of
@@ -58,6 +58,7 @@ class QGroupBox;
 class KListEditor;
 class ToolSelectionWidget;
 class KIntNumInput;
+class KURLRequester;
 
 struct ModuleInfo;
 
@@ -198,6 +199,7 @@ private:
 
     QCheckBox* _killButton;
     QCheckBox* _indexButton;
+    QCheckBox* m_msgfmtButton;
 };
 
 class DirCommandsPreferences : public QWidget
@@ -276,7 +278,7 @@ signals:
     void itemsChanged ();
 
 private:
-    QLineEdit* _coderootEdit;
+    KURLRequester* _coderootEdit;
     KListEditor* _pathsEditor;
 };
 
