@@ -18,7 +18,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
   In addition, as a special exception, the copyright holders give
   permission to link the code of this program with any edition of
@@ -459,7 +459,7 @@ void KBabelMW::setupActions()
            , actionCollection(),"insert_next_tag");
    connect(m_view,SIGNAL(signalNextTagAvailable(bool)),action
            ,SLOT(setEnabled(bool)));
-   action = new KAction(i18n("Insert Next Tag From Msgid P&osition"), "insert_tag", CTRL+ALT+Key_M
+   action = new KAction(i18n("Insert Next Tag From Msgid P&osition"), "insert_tag", CTRL+Key_M
            , m_view, SLOT(insertNextTagMsgid())
            , actionCollection(),"insert_next_tag_msgid");
    connect(m_view,SIGNAL(signalNextTagAvailable(bool)),action
@@ -478,11 +478,11 @@ void KBabelMW::setupActions()
    connect(m_view,SIGNAL(signalTagsAvailable(bool)),action
            ,SLOT(setEnabled(bool)));
 
-   action = new KAction(i18n("Move to Next Tag"), 0, CTRL+Key_Plus
+   action = new KAction(i18n("Move to Next Tag"), 0, CTRL+ALT+Key_M
            , m_view, SLOT(skipToNextTag())
            , actionCollection(),"move_to_next_tag");
 
-   action = new KAction(i18n("Move to Previous Tag"), 0, CTRL+Key_Minus
+   action = new KAction(i18n("Move to Previous Tag"), 0, CTRL+ALT+Key_B
            , m_view, SLOT(skipToPreviousTag())
            , actionCollection(),"move_to_prev_tag");
 
@@ -880,15 +880,6 @@ void KBabelMW::restoreSettings()
     {
        a_recent->loadEntries(_config);
 
-       // cleanup maybe broken list
-       QStringList list = a_recent->items();
-       QStringList result;
-       for ( QStringList::Iterator it = list.begin(); it != list.end(); ++it ) {
-           KURL u( *it );
-           if( u.isValid() && !u.isEmpty() ) result.append( *it );
-       }
-       a_recent->setItems(result);
-
        a_recentprojects->loadEntries(_config, "Project");
     }
 }
