@@ -1,7 +1,7 @@
 /* ****************************************************************************
   This file is part of KBabel
 
-  Copyright (C) 2004  by Stanislav Visnovsky
+  Copyright (C) 2004-2005  by Stanislav Visnovsky
 			    <visnovsky@kde.org>
 
   This program is free software; you can redistribute it and/or modify
@@ -16,7 +16,18 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+
+  In addition, as a special exception, the copyright holders give
+  permission to link the code of this program with any edition of
+  the Qt library by Trolltech AS, Norway (or with modified versions
+  of Qt that use the same license as Qt), and distribute linked
+  combinations including the two.  You must obey the GNU General
+  Public License in all respects for all of the code used other than
+  Qt. If you modify this file, you may extend this exception to
+  your version of the file, but you are not obligated to do so.  If
+  you do not wish to do so, delete this exception statement from
+  your version.
 
 **************************************************************************** */
 #ifndef SOURCEVIEW_H
@@ -37,6 +48,7 @@ public:
 
 public slots:
     virtual void updateView();
+    virtual void setProject(KBabel::Project::Ptr project);
     
 private:
     SourceContext* _contextView;
