@@ -1,6 +1,6 @@
 ;; kde-emacs-utils.el
 ;;
-;; Copyright (C)  2002  KDE Development Team <www.kde.org>
+;; Copyright (C)  2002-2005  KDE Development Team <www.kde.org>
 ;;
 ;; This library is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU Lesser General Public
@@ -28,170 +28,293 @@
       (add-hook 'find-file-hooks 'fume-add-menubar-entry))
   (require 'imenu))
 
+(defmacro c-safe-scan-lists (from count depth)
+  "Like `scan-lists' but returns nil instead of signalling errors.
+This function does not do any hidden buffer changes."
+  (if (featurep 'xemacs)
+      `(scan-lists ,from ,count ,depth nil t)
+    `(c-safe (scan-lists ,from ,count ,depth))))
+
+;; returns non-nil if the given file has a using declaration
+;; with the passed namespace
+(defun kde-file-has-using (namespace)
+  (let (found)
+    (save-excursion
+      (beginning-of-buffer)
+      (setq found (re-search-forward "^using" nil 1))
+      (if found
+	  (setq found (search-forward namespace (line-end-position) 1))
+	)
+      )
+    found)
+  )
+
+;; returns non-nill if the given file has a "namespace SomeNM" declaration
+;; where SomeNM is passed via the namespace argument
+(defun kde-file-is-in-namespace (namespace)
+  (let (found)
+    (save-excursion
+      (beginning-of-buffer)
+      (setq found (re-search-forward "^namespace" nil 1))
+      (if found
+	  (setq found (search-forward namespace (line-end-position) 1))
+	)
+      )
+    found)
+  )
+
+; Helper function for parsing our current position in a C++ header file
+; returns (namespace (class function)) where (a b) is a cons.
+(defun method-under-point ()
+  (let ((class nil)
+        (namespace "") ; will contain A::B::
+        (function nil))
+    (save-excursion
+      (backward-char)             ; in case we're after the ';'
+      (search-forward ";" nil t)  ; look for the ';'
+      (backward-char)
+      (save-excursion
+        ; Go up a level, skipping entire classes etc.
+        ; This is a modified version of (backward-up-list) which doesn't
+        ; throw an error when not found.
+	(let ((pos (c-safe-scan-lists (point) -1 1)))
+	; +1 added here so that the regexp in the while matches the { too.
+	  (goto-char (if pos (+ pos 1) (point-min))))
+	(while (re-search-backward "^[ ]*\\(class\\|namespace\\)[ \t][^};]*{" nil t)
+	  (save-excursion
+	    (forward-word 1)
+	   (when (looking-at "[ \t]*[A-Z_]*_EXPORT[A-Z_]*[ \t]")
+	     (forward-word 1)
+	     (re-search-forward "[ \t]" nil t))
+	    (while (looking-at "[ \t]")
+	      (forward-char 1))
+	    (setq start (point))
+	    ; Parse class name ("Foo" or "Foo::Bar::Blah"). 
+	    ; Beware of "Foo:"
+	    (while (or (looking-at "[A-Za-z0-9_]") (looking-at "::"))
+	      (while (looking-at "[A-Za-z0-9_]")
+		(forward-char 1))
+	      (while (looking-at "::")
+		(forward-char 2))
+	      )
+	    (cond
+	     (class			; class found already, so the rest goes into the namespace
+	      (setq namespace (concat (buffer-substring start (point)) "::" namespace)))
+	     (t				; class==nil
+	      (setq class (buffer-substring start (point)))))
+	    )
+        ; Go up one level again
+	(let ((pos (c-safe-scan-lists (point) -1 1)))
+	  (goto-char (if pos (+ pos 1) (point-min))))
+	))
+
+    ; Back to where we were, parse function name
+    (let ((end (point)))          ; remember where the function decl ends
+      (search-backward ")" nil t) ; look back for the end of the argument list
+      (forward-char)
+      (backward-sexp)             ; brings us back to the '('
+      (backward-word 1)
+      (when (looking-at "throw[ \t]") ; exception specification, look for () again
+             (search-backward ")" nil t)
+             (forward-char)
+             (backward-sexp))
+      ; now that we moved back enough, go to beginning of line.
+      ; (we assume that the return type, function name, and '(' are on the same line)
+      (re-search-backward "^[ \t]*")
+      (while (looking-at "[ \t]")
+	(forward-char 1))
+      (setq function (buffer-substring (point) end))
+      )
+    ) ; end of global save-excursion
+    (cons namespace (cons class function)) ; the returned value
+    )
+  )
+
+; get rid of virtual, static, multiple spaces, default values.
+(defun canonical-function-sig (function)
+  (and (string-match "[ \t]*\\<virtual\\>[ \t]*" function)
+       (setq function (replace-match " " t t function)))
+  (and (string-match "^\\(virtual\\>\\)?[ \t]*" function)
+       (setq function (replace-match "" t t function)))
+  (and (string-match "^\\(static\\>\\)?[ \t]*" function)
+       (setq function (replace-match "" t t function)))
+  (while (string-match "  +" function) ; simplifyWhiteSpace
+    (setq function (replace-match " " t t function)))
+  (while (string-match "\t+" function)
+    (setq function (replace-match " " t t function)))
+  (while (string-match "^ " function)  ; remove leading whitespace
+    (setq function (replace-match "" t t function)))
+  (let ((startargs (string-match "(" function)))
+    (while (string-match " ?=[^,)]+" function startargs) ; remove default values
+      (setq function (replace-match " " t t function))))
+  (while (string-match " +," function) ; remove space before commas
+    (setq function (replace-match "," t t function)))
+  function ; the return value
+)
+
+; Helper method which turns the function as seen in the header
+; into the signature for its implementation
+; Returns the fully-qualified signature of the function implementation
+(defun kde-function-impl-sig (namespace class _function)
+  (let (
+	(function (canonical-function-sig _function))
+	(insertion-string nil))
+    (and (stringp class)
+	 (cond
+	  ((string-match (concat "^ *" class "[ \\t]*(") function) ; constructor
+	   (setq insertion-string
+		 (replace-match
+		  (concat namespace class "::" class "(")
+		  t t function)
+		 ))
+	  ((string-match (concat "^ *~" class "[ \\t]*(") function) ; destructor
+	   (setq insertion-string
+		 (replace-match
+		  (concat namespace class "::~" class "(")
+		  t t function)
+		 ))
+	  ))				; end of "class required"
+    (if (not (stringp insertion-string)) ; no ctor nor dtor
+	(if (or (string-match " *\\([a-zA-Z0-9_]+\\)[ \\t]*(" function) ; normal method
+		(string-match " *\\(operator[^ \\t]+\\)[ \\t]*(" function)) ; operator
+	      (setq insertion-string
+		    (replace-match
+		     (if class
+			 (concat " " namespace class "::" "\\1(") ; c++ method
+		       (concat " " "\\1(")) ; c function
+		     t nil function)
+		    )
+					; else
+	  (error (concat "Can't parse declaration ``"
+			 function "'' in class ``" class
+			 "'', aborting"))))
+    insertion-string ; the return value
+    )
+  )
+
 ;; Switch between the declaration of a class member in .cc/.cpp/.C, and its definition in the .h file
 ;; Written by David and Reggie after much hair tearing
+;; Found since, might be worth looking at: http://www.hendawi.com/emacs/sourcepair.el
 (defun switch-to-function-def ()
   (interactive)
   (let ((n (buffer-file-name))
+        (namespace "")
         (class "")
-        (fn "")
-	(save)
+        (function "")
+        found
 	)
     (if (or (string-match "\\.cc$" n)
             (string-match "\\.cpp$" n)
             (string-match "\\.C$" n))
+        ; TODO replace fume-function-before-point, needed for emacs,
+        ; and for better namespace support.
+	;(progn
+	;  (let ((pos (kde-scan-lists (point) -1 1 nil t))) ; Go up a level
+	;    (goto-char (if pos (+ pos 1) (point-min))))
         (let ((a (fume-function-before-point)))
           (and (string-match "^\\(.*\\)::\\(.*\\)$" a)
                (progn
                  (setq class (match-string 1 a))
-                 (setq fn (match-string 2 a))
+                 (setq function (match-string 2 a))
                  (kde-switch-cpp-h)
                  (goto-char 0)
                  (re-search-forward
 		  (concat "\\(class\\|struct\\|namespace\\)\\s-+"
 			  class "[^;]+{") nil t)
                  ;; TODO keep looking, until we find a match that's not inside a comment
-                 (re-search-forward (concat "[ \t]+" fn "[ \t]*(") nil t)))))
+                 (re-search-forward (concat "[ \t]+" (regexp-quote function) "[ \t]*(") nil t)))))
     (if (string-match "\\.h$" n)
         (progn
-          (save-excursion
-            (forward-line 0)
-            (re-search-forward "[ \t]+\\([^ \t(]+\\)[ \t]*(" nil t)
-            (setq fn (match-string 1))
-            (re-search-backward "^\\(class\\|namespace\\) \\([a-zA-Z0-9_]+\\)[ \t]*\\([a-zA-Z0-9_]*\\)" nil t)
-            (setq class (match-string 2))
-            (setq save (match-string 3))
-            (and (string-match "Q_EXPORT" class)
-                 (setq class save))
-            (message (concat class "::" fn))
-            )
-          (kde-switch-cpp-h)
-          (goto-char 0)
-          (re-search-forward (concat "^[^()]*" class "::" fn "[ \t]*(") nil t)
-          (message c-syntactic-context)
-          )
-)))
+	  (let ((mup (method-under-point))
+		(sig "")
+		(pos 0))
+        (setq namespace (car mup))
+	    (setq class (car (cdr mup)))
+	    (setq function (cdr (cdr mup)))
+	    (kde-switch-cpp-h)
 
-; Credits to Arnt
+        ;; First search with namespace prefixed
+	    (goto-char 0)
+	    (setq sig (kde-remove-newline (kde-function-impl-sig namespace class function)))
+	    (if (string-match "(.*" sig) ; remove args
+		(setq sig (replace-match "" nil t sig)))
+	    (setq found (re-search-forward (concat "^[^()]*" (regexp-quote sig) "[ \t]*(") nil t) )
+
+        (if (not found)
+            (progn
+              ; Now search without name space prefix
+
+              (goto-char 0)
+              (setq sig (kde-remove-newline (kde-function-impl-sig "" class function)))
+              
+              (if (string-match "(.*" sig) ; remove args
+                  (setq sig (replace-match "" nil t sig)))
+              (re-search-forward (concat "^[^()]*" (regexp-quote sig) "[ \t]*(") nil t) ) )
+	    )))))
+
+(defun kde-remove-newline (str) 
+  (let ((res str))
+    (while (string-match "\n" res )
+    (setq res (replace-match " " nil t res)))
+  res))
+
+; Initial implementation by Arnt Gulbransen
+; Current maintainer: David Faure
 (defun agulbra-make-member ()
   "make a skeleton member function in the .cpp or .cc file"
   (interactive)
-  (let ((class nil)
-        (function nil)
-        (file (buffer-file-name))
-        (insertion-string nil)
-	(msubstr nil)
-        (start nil))
+  (let* (
+	 (mup (method-under-point))
+	 (namespace (car mup))  ; will contain A::B::
+	 (class (car (cdr mup)))
+	 (function (cdr (cdr mup)))
+	 (file (buffer-file-name))
+	 (insertion-string (kde-function-impl-sig namespace class function))
+	 (msubstr nil)
+	 (start nil)
+	 )
+    (setq insertion-string 
+	  (concat insertion-string "\n{\n"
+		  (replace-in-string kde-make-member-default-impl "FUNCTION" 
+				     ; the function name and args, without newlines
+				     (replace-in-string insertion-string "\n" " " t)
+				     t)
+		  "}\n"))
+    ; move to next method, to be ready for next call
+    (backward-char)                ; in case we're after the ';'
+    (re-search-forward ";" nil t)  ; end of this method decl
+    (re-search-forward ";" nil t)  ; end of next method decl
+
+    (if (string-match "\\.h$" file)
+	(kde-switch-cpp-h)
+      )
+    (goto-char (point-max))
+    (kde-comments-begin)
+    (kde-skip-blank-lines)
+    (setq msubstr (buffer-substring (point-at-bol) (point-at-eol)))
+    (if (string-match "^#include.*moc.*" msubstr)
+	(progn 
+	  (forward-line -1)
+	  (end-of-line)
+	  (insert "\n")))
+    (if (string-match "}" msubstr)
+	(progn
+	  (end-of-line)
+	  (insert "\n")
+	  (forward-line 1)
+	  ))
+    (insert insertion-string)
+    (forward-char -3)
+    (c-indent-defun)   
     (save-excursion
-      (and (re-search-backward "^\\(class\\|namespace\\)[ \t]" nil t)
-           (progn
-             (forward-word 1)
-             (while (looking-at "[ \t]*Q_EXPORT")
-               (forward-word 2))
-             (while (looking-at "[ \t]")
-               (forward-char 1))
-             (setq start (point))
-             (while (looking-at "[A-Za-z0-9_]")
-               (forward-char 1))
-             (setq class (buffer-substring start (point))))))
-    (progn
-      (and (looking-at "$")
-           (progn
-             (search-backward ")" nil t)
-             (forward-char)
-             (backward-sexp)))
-      (and (stringp class)
-           (re-search-backward "^[ \t]*")
-           (progn
-             (while (looking-at "[ \t]")
-               (forward-char 1))
-             (setq start (point))
-             (and (search-forward "(" nil t)
-                  (progn
-                    (forward-char -1)
-                    (forward-sexp)))
-             (and (looking-at "[ \t]+const")
-                  (forward-word 1))
-             (and (looking-at ";")
-                  (setq function (buffer-substring start (point))))
-             (re-search-forward "(" nil t))))
-    (and (stringp function)
-         (progn ;; get rid of virtual, static, multiple spaces, default values.
-           (and (string-match "[ \t]*\\<virtual\\>[ \t]*" function)
-                (setq function (replace-match " " t t function)))
-           (and (string-match "^\\(virtual\\>\\)?[ \t]*" function)
-                (setq function (replace-match "" t t function)))
-           (and (string-match "^\\(static\\>\\)?[ \t]*" function)
-                (setq function (replace-match "" t t function)))
-           (while (string-match "  +" function)
-             (setq function (replace-match " " t t function)))
-           (while (string-match "\t+" function)
-             (setq function (replace-match " " t t function)))
-           (while (string-match " ?=[^,)]+" function)
-             (setq function (replace-match " " t t function)))
-           (while (string-match " +," function)
-             (setq function (replace-match "," t t function)))))
-    (and (stringp function)
-         (stringp class)
-         (stringp file)
-         (progn
-           (cond ((string-match (concat "^ *" class "[ \\t]*(") function)
-                  (progn
-                  (setq insertion-string
-                        (concat
-                         (replace-match
-                          (concat class "::" class "(")
-                          t t function)
-                         "\n{\n    \n}\n"))))
-                  ((string-match (concat "^ *~" class "[ \\t]*(") function)
-                   (progn
-                     (setq insertion-string
-                           (concat
-                            (replace-match
-                             (concat class "::~" class "(")
-                             t t function)
-                            "\n{\n    \n}\n"))))
-                  ((string-match " *\\([a-zA-Z0-9_]+\\)[ \\t]*(" function)
-                   (progn
-                     (setq insertion-string
-                           (concat
-                            (replace-match
-                             (concat " " class "::" "\\1(")
-                             t nil function)
-                            "\n{\n    \n}\n"))))
-                  (t
-                   (error (concat "Can't parse declaration ``"
-                                  function "'' in class ``" class
-                                  "'', aborting"))))
-           (stringp insertion-string)))
-	 (kde-switch-cpp-h)
-         (progn
-           (goto-char (point-max))
-	   (kde-comments-begin)
-	   (kde-skip-blank-lines)
-	   (setq msubstr (buffer-substring (point-at-bol) (point-at-eol)))
-	   (if (string-match "^#include.*moc.*" msubstr)
-	       (progn 
-		 (forward-line -1)
-		 (end-of-line)
-		 (insert "\n")))
-	   (if (string-match "}" msubstr)
-	       (progn
-		 (end-of-line)
-		 (insert "\n")
-		 (forward-line 1)
-	     ))
-	   (insert insertion-string)
-	   (forward-char -3)
-	   (c-indent-command)
-	   (save-excursion
-	     (and (string-match ".*/" file)
-		  (setq file (replace-match "" t nil file)))
-             (if (functionp 'kdab-insert-include-file)
-                 (kdab-insert-include-file file 't nil)))))
-  (when (featurep 'fume-rescan-buffer)
-    (fume-rescan-buffer))
-  )
+      (and (string-match ".*/" file)
+	   (setq file (replace-match "" t nil file)))
+      (and (string-match "\\.h$" file)
+	   (functionp 'kdab-insert-include-file)
+	   (kdab-insert-include-file file 't nil)))
+    (when (featurep 'fume-rescan-buffer)
+      (fume-rescan-buffer))
+    ))
 
 
 ; Adds the current file to Makefile.am.
@@ -271,7 +394,7 @@
 ; Makes '(' insert '(' or ' ( ' where appropiate
 (defun insert-parens (arg) (interactive "*P")
   (if (not (c-in-literal))
-      (let ((n nil))
+      (let ((n nil) (except nil))
         (save-excursion
           (setq n (or (progn (forward-char -2) (looking-at "if"))
                       (progn (forward-char -1) (looking-at "for"))
@@ -279,6 +402,11 @@
                       (progn (forward-char -1) (looking-at "while"))
                       )
                 )
+          (setq except (or (progn (forward-char -2) (looking-at "kdDebug"))
+                           (looking-at "kdError")
+                           (progn (forward-char -2) (looking-at "kdWarning"))
+			   )
+                )
           )
         (cond
          (n (progn
@@ -288,7 +416,7 @@
               ))
          (t ;else
           (self-insert-command (prefix-numeric-value arg))
-          (insert kde-emacs-after-parent-string)
+          (cond ((not except) (insert kde-emacs-after-parent-string)))
           )))
     (self-insert-command (prefix-numeric-value arg)))
   )
@@ -299,7 +427,20 @@
         (forward-char -2)
         (setq remv (looking-at "( ")) ; () -> we'll have to remove that space
         (forward-char 1)
-        (setq nospac (or (looking-at " ") (looking-at "(")) ) ; no space to be added
+        (setq nospac ; no space to be added
+              (or (looking-at " ")
+                  (looking-at "(")
+                  (save-excursion ; check for kdDebug(123
+                    (while (looking-at "[0-9]")
+                      (forward-char -1))
+                    (forward-char -7)
+                    (or (looking-at "kdDebug(")
+			(looking-at "kdError(")
+                           (progn (forward-char -2) (looking-at "kdWarning("))
+			   )
+		    )
+                  )
+              )
         (forward-char 1)
         (cond
          (remv (progn
@@ -409,34 +550,39 @@
 (defun makeclean ()
   "Executes a \"make clean\" in the current directory"
   (interactive)
-  (compile "make clean")
+  (compile (concat kde-emacs-make " clean"))
   )
 
 (defun make ()
   "Executes a \"make\" in the current directory"
   (interactive)
-  (compile "make -k")
+  (compile (concat kde-emacs-make " -k"))
   )
 
 (defun makeinstall ()
   "Executes a \"make install\" in the current directory"
   (interactive)
-  (compile "make -k install")
+  (compile (concat kde-emacs-make " -k install"))
   )
 
 (defun makeinstallexec ()
   "Executes a \"make install-exec\" in the current directory"
   (interactive)
-  (compile "make -k install-exec")
+  (compile (concat kde-emacs-make " -k install-exec"))
   )
 
 (defun makethisfile ()
   "Try to compile the currently opened file"
   (interactive)
-  (let ((f (file-name-nondirectory (buffer-file-name))))
-    (if (string-match "\.cpp$" f) (setq f (replace-match "\.lo" t t f)))
-    (if (string-match "\.cc$" f) (setq f (replace-match "\.lo" t t f)))
-    (compile (concat "make " f )))
+  (let ((f (file-name-nondirectory (buffer-file-name)))
+	(objext nil))
+
+    (if (file-readable-p "Makefile.am")
+	(setq objext "\.lo")
+      (setq objext "\.o"))
+    (if (string-match "\.cpp$" f) (setq f (replace-match objext t t f)))
+    (if (string-match "\.cc$" f) (setq f (replace-match objext t t f)))
+    (compile (concat kde-emacs-make " " f)))
   )
 
 ;; pc-like textmarking
@@ -575,7 +721,7 @@
   (let ((wascomment ""))
     (save-excursion
       (beginning-of-buffer)
-      (if (re-search-forward (concat "Copyright ([Cc]) \\([0-9 ,-]*\\) " kde-full-name) nil t)
+      (if (re-search-forward (concat "Copyright ([Cc]) \\([0-9 ,-]*\\) " (regexp-quote kde-full-name)) nil t)
 	  (progn
 	    (beginning-of-line)
 	    (let ((years (kde-year-range-cleanup (kde-year-range-parse-years-string (match-string 1))))
@@ -652,5 +798,45 @@
 	  (comment-region (point-at-bol) (point-at-eol))
 	  (newline)))))
 
+; Helper for qt-open-header, for Qt 4. Opens a file if it says #include "../foo/bar.h",
+; close it and open that file instead; recursively until finding a real file.
+(defun qt-follow-includes (file)
+  (let ((line "")
+	(begin nil)
+	(buffer nil))
+    (find-file file)
+    (goto-char 0)
+    (if (looking-at "#include \"")
+	(progn
+	  (forward-char 10)
+	  (setq begin (point))
+	  (re-search-forward "\"" nil t)
+	  (backward-char 1)
+	  (setq file (buffer-substring begin (point)))
+	  (setq buffer (current-buffer))
+	  (qt-follow-includes file)
+	  (kill-buffer buffer)
+	  )
+      ; else: this is the right file, skip the comments and go to the class
+      (progn
+	(re-search-forward "^class" nil t)
+	(beginning-of-line))
+    )))
+
+(defun qt-open-header ()
+  "Open the Qt header file for the class under point"
+  (interactive)
+  (let* ((file (getenv "QTDIR"))
+	(class (thing-at-point 'word))
+	(f nil)
+	(files (directory-files (concat file "/include") t nil "dirsonly"))
+	)
+    (save-excursion
+      (dolist (f files nil)
+	(if (file-readable-p (concat f "/" class) )
+	    (setq file (concat f "/" class))))
+      (qt-follow-includes file)
+      )
+  ))
 
 (provide 'kde-emacs-utils)
