@@ -1,3 +1,8 @@
+/*
+ *  copyright (C) 2004
+ *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
+ */
+
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -17,7 +22,7 @@ class QMouseEvent;
 class UMLView;
 class UMLWidget;
 
-/** 
+/**
  * Almost every object is created by this state. Except assiociations and
  * messages. 
  */ 
@@ -25,22 +30,19 @@ class ToolBarStateOther : public ToolBarStatePool
 {
 
 public:
-	ToolBarStateOther(UMLView *umlView);	
-	virtual ~ToolBarStateOther();	
+    ToolBarStateOther(UMLView *umlView);
+    virtual ~ToolBarStateOther();
+
+    virtual void mousePress(QMouseEvent* ome);
+    virtual void mouseRelease(QMouseEvent* ome);
+    virtual void mouseDoubleClick(QMouseEvent* ome);
+    virtual void mouseMove(QMouseEvent* ome);
 
-	virtual void mousePress(QMouseEvent* ome);
-	virtual void mouseRelease(QMouseEvent* ome);
-	virtual void mouseDoubleClick(QMouseEvent* ome);
-	virtual void mouseMove(QMouseEvent* ome);
-	
 private:
 
-	Uml::UMLObject_Type getObjectType(WorkToolBar::ToolBar_Buttons tbb);
-	bool newWidget();
+    Uml::Object_Type getObjectType(WorkToolBar::ToolBar_Buttons tbb);
+    bool newWidget();
 
-	void floatingTextSetup(UMLWidget* umlWidget);
-	void activityWidgetSetup(UMLWidget* umlWidget);
-	void stateWidgetSetup(UMLWidget* umlWidget);
 };
 
 #endif //TOOLBARSTATEOTHER_H
